@@ -58,29 +58,29 @@
     <div class="searchBar">
       <table class="searchBar">
         <tr>
-          <td style="text-align: left; vertical-align: middle">
-            Bacula, l'outil de sauvegarde r&eacute;seau pour Linux, Unix, Mac et
-            Windows.
+          <td style="text-align: left; vertical-align: middle; width: 50%">
+            Bacula, l'outil de sauvegarde r&eacute;seau pour Linux, Unix, Mac et Windows.
           </td>
           <td style="text-align: left; vertical-align: middle">
+              <img alt="Fran&ccedil;ais" src="../images/french-flag.jpg">
+              &nbsp;&nbsp;&nbsp;
             <a href='/'>
               <img alt="English" src="../images/english-flag.jpg">
             </a>&nbsp;&nbsp;&nbsp;
-            <a href='/fr'>
-              <img alt="Fran&ccedil;ais" src="../images/french-flag.jpg">
+            <a href='/de'>
+              <img alt="Deutsch" src="../images/german-flag.jpg">
             </a>
           </td>
+          <FORM method=GET  target="_blank" action=http://www.google.com/search>
           <td style="text-align: right; vertical-align: middle">
-            <form method=GET  target="_blank"
-              action=http://www.google.com/search>
               <input id="text" class="searchBar" type="text" name="q" size=20
                maxlength=255 value="">
-              <input id="button" class="searchBar" type="submit" name="sa"
+              <INPUT id="button" class="searchBar" type="submit" name="sa"
                value="Recherche">
               <input type="hidden" name="domains" value="www.bacula.org">
               <input type="hidden" name="sitesearch" value="www.bacula.org">
-            </form>
           </td>
+          </FORM>
         </tr>
       </table>
     </div>
@@ -112,36 +112,20 @@
       <div class="menuHead"> G&eacute;n&eacute;ral </div>
       <div class="menuItem">
         <ul class="menuitem">
-          <li class="menuItem"> <a href="<? echo $spath ?>/?page=news">
-            Actualit&eacute;s </a></li>
-          <li class="menuItem"> <a href="<? echo $spath ?>/?page=home">
-            Page d'accueil </a></li>
-          <li class="menuItem"> <a 
-            href="dev-manual-fr/Qu_est_ce_que_Bacula.html">
-            Qu'est-ce que Bacula? </a></li>
-          <li class="menuItem"> <a
-            href="dev-manual-fr/L_etat_actuel_de_Bacula.html">
+          <li class="menuItem"> <a href="<? echo $spath ?>/?page=news"> Actualit&eacute;s </a></li>
+          <li class="menuItem"> <a href="<? echo $spath ?>/?page=home"> Page d'accueil </a></li>
+          <li class="menuItem"> <a href="dev-manual/Qu_est_ce_que_Bacula.html"> Qu'est-ce que Bacula? </a></li>
+          <li class="menuItem"> <a href="dev-manual/etat_actuel_Bacula.html">
             L'&eacute;tat actuel de Bacula </a></li>
-          <li class="menuItem"> <a
-            href="dev-manual-fr/Bacula_Copyri_Tradem_Licens.html"> License
-            </a></li>
-          <li class="menuItem"> <a
-            href="<? echo $spath ?>/?page=testimonials"> T&eacute;moignages</a></li>
-          <li class="menuItem"> <a 
-            href="http://sourceforge.net/projects/bacula"> Lien du projet SF
-            </a> </li>
-          <li class="menuItem"> <a
-            href="dev-manual-fr/Caract_syst_ge_indisp.html"> Pr&eacute;-requis </a>
-          </li>
-          <li class="menuItem"> <a 
-            href="dev-manual-fr/Syste_d_exploi_support.html"> OS support&eacute;s
-            </a>
+          <li class="menuItem"> <a href="dev-manual/Bacula_Copyrig_Tradema_and.html"> License </a></li>
+          <li class="menuItem"> <a href="<? echo $spath ?>/?page=testimonials"> T&eacute;moignages</a></li>
+          <li class="menuItem"> <a href="http://sourceforge.net/projects/bacula"> Lien du projet SF </a> </li>
+          <li class="menuItem"> <a href="dev-manual/Caract_syst_ge_indisp.html"> Pr&eacute;-requis </a> </li>
+          <li class="menuItem"> <a href="dev-manual/Systemese_supportes.html"> OS support&eacute;s  </a>
           </li>
           <li class="menuItem"> <a
-            href="dev-manual-fr/Lecteurs_de_bandes_support"> Lecteurs de
-            bandes support&eacute;s</a> </li>
-          <li class="menuItem"> <a
-            href="dev-manual-fr/Autochanger_Support.html"> Autochangers </a>
+            href="dev-manual/Lecteurs_bandes_supporte.html"> Lecteurs de bandes support&eacute;s</a> </li>
+          <li class="menuItem"> <a href="dev-manual/Support_librairies.html"> Librairies support&eacute;es </a>
           </li>
         </ul>
       </div>
@@ -169,7 +153,7 @@
             href="http://sourceforge.net/project/showfiles.php?group_id=50727#files">
             Toutes les versions </a> </li>
           <li class="menuItem"> <a
-            href="http://sourceforge.net/cvs/?group_id=50727"> D&eacute;p&ocirc;t CVS 
+            href="http://sourceforge.net/svn/?group_id=50727"> D&eacute;p&ocirc;t SVN 
             </a></li>
         </ul>
       </div>
@@ -217,7 +201,7 @@
   
       <div class="menuHead"> </div>
       <div class="icons">
-        <a href="http://www.sectoor.de"><img src="http://www.sectoor.de/grafiken/button_klein2.png" alt="Sectoor Logo"></a>
+        <!-- a href="http://www.sectoor.de"><img src="http://www.sectoor.de/grafiken/button_klein2.png" alt="Sectoor Logo"></a -->
            <!-- a href="http://validator.w3.org/check?uri=referer"><img src="images/valid-xhtml10.png" alt="valix w3c logo"></a -->
            <!-- a href="http://jigsaw.w3.org/css-validator/validator?uri=<? echo $_SERVER['HTTP_REFERER']; ?>"><img src="images/vcss.png" alt="valid css logo"></a-->
       </div>
