@@ -8,15 +8,15 @@
   <tr>
     <td class="content">
       <p>
-        Les personnes suivantes sont des entrepreneurs indpendants. Ils ont
-        tous travaill avec Bacula et nous sommes heureux de lister leur nom
+        Les personnes suivantes sont des entrepreneurs ind&eacute;pendants. Ils ont
+        tous travaill&eacute; avec Bacula et nous sommes heureux de lister leur nom
         ici comme un service, mais sans garanties.
         <br>
-        Merci de lire cette courte <a href="?page=listlic">'licence'</a> 
-        propos du support professionnel. Tous les noms ont t revus et
-        approuvs.
+        Merci de lire cette courte <a href="?page=listlic">'licence'</a> &aacute;
+        propos du support professionnel. Tous les noms ont &eacute;t&eacute; revus et
+        approuv&eacute;s.
         <br>
-        Toutes les adresses email ont t tendues avec un tag 'NOSPAM'. Merci
+        Toutes les adresses email ont &eacute;t&eacute; &eacute;tendues avec un tag 'NOSPAM'. Merci
         de le supprimer avant d'envoyer un email.
       <p>
     </td>
