@@ -46,7 +46,7 @@
       <meta name="Description" content="Bacula a network backup and restore program">
       <meta name="Keywords" content="Bacula, backup, restore, file backup">
       <meta name="Copyright" content="Copyright (C) 2000-2007 Kern Sibbald">
-      <meta name="Trademark" content="Bacula (R) is a registered trademark of John Walker">
+      <meta name="Trademark" content="Bacula (R) is a registered trademark of Kern Sibbald">
    </head>
 
    <body>
