@@ -28,8 +28,6 @@
     <br>(released version of the User's Manual)<br></li>
    <li> <a href="<? echo $spath ?>/rel-bacula.pdf">PDF User's Manual</a>
     <br>(released version of the User's Manual)<br></li>
-   <li> <a href="<? echo $spath ?>/rel-bacula-doc.tar.gz">tarred Manual</a>
-    <br>(released version of the User's Manual)</li>
    </ul>
    </td>
    <td class="content">
