@@ -170,6 +170,33 @@
               </td>
       </tr>
 
+
+      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
+      <tr> <td colspan="3"><hr></td>
+      <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
+      <tr>
+              <td style="font-weight: bold">
+                     HEXONET Support GmbH
+              </td>
+              <td><img src="images/spacer.gif" width="50px" height="1px"></td>
+              <td>
+                 <a href="mailto:infoNOSPAM@hexonet.com">Hexonet</a><br>
+                 Alexander Biehl<br>
+                 Talstrasse 27<br>
+                 66424 Homburg<br>
+                 Germany 
+                 <br>
+                 Tel: +49 6841 95961-70<br>
+                 Fax: +49 6841 95961-79<br>
+                 <br>
+                 HEXONET Support GmbH provides professional IT services and support. We 
+                 are specialized in OpenSource products.
+                 <br>
+                 <a href="http://www.hexonet.com">http://www.hexonet.com</a><br>
+              </td>
+      </tr>
+
+
       <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
       <tr> <td colspan="3"><hr></td>
       <tr> <td colspan="3"><img src="images/spacer.gif" width="50px" height="25px"></td> </tr>
