@@ -17,6 +17,11 @@
    <a href="http://news.gmane.org/search.php?match=bacula">
    http://news.gmane.org/search.php?match=bacula</a>.
 
+   Also, if you are using Bacula in production, we highly recommend
+   subscribing to the bugs database at: <a href="http://bugs.bacula.org">
+   http://bugs.bacula.org</a> to keep informed of problems and 
+   patches.
+
    <p>For support, send an email to
    <b>bacula-users at lists.sourceforge.net</b>, and if you are
    specific enough, some kind Bacula user will help you. Please
